@@ -22,6 +22,77 @@ If using, a basic file may look like::
           registeredTasks:
               - handler: sermos_demo_client.workers.demo_worker.demo_task
 
+
+    imageConfig:
+        - name: base-image
+            installCommand: sermos-demo-client
+            sourceSshUrl: git@gitlab.com:sermos/sermos-demo-client.git
+            baseImage: registry.gitlab.com/sermos/sermos-tools:0.3.0
+
+    serviceConfig:
+        - name: demo-api
+            serviceType: external
+            serviceId: ${SERVICE_ID_API}  # Rendered using `sermos deploy` if available in the environment.
+            imageName: base-image
+            command: gunicorn --log-level info -k gevent -b 0.0.0.0:5000 sermos_demo_client.app:create_app()
+            port: 5000
+            replicaCount: 1
+            cpuLimit: 0.5
+            memoryLimit: 0.5
+            environmentVariables:
+            - name: FLASK_SECRET_KEY
+                value: ${FLASK_SECRET_KEY}
+        - name: sermos-worker
+            serviceType: celery-worker
+            serviceId: ${SERVICE_ID_WORKER}
+            imageName: base-image
+            command: celery -A sermos_demo_client.celery worker --without-gossip --without-mingle -c '1' -l INFO --queue default-task-queue
+            replicaCount: 1
+            cpuLimit: 0.5
+            memoryLimit: 0.5
+            registeredTasks:
+                - handler: sermos_demo_client.workers.demo_worker.demo_worker_task
+                - handler: sermos_demo_client.workers.demo_worker.demo_model_task
+            environmentVariables:
+            - name: WORKER_NAME
+                value: sermos-worker
+
+    pipelines:
+        demo-pipeline:
+            name: demo-pipeline
+            description: Demo Pipeline.
+            schemaVersion: 1
+            config:
+                dagAdjacency:
+                    node_a:
+                        - node_b
+                        - node_c
+                metadata:
+                    maxRetry: 3
+                    maxTtl: 60
+                    queue: default-task-queue
+                taskDefinitions:
+                    node_a:
+                        handler: sermos_demo_client.workers.demo_pipeline.demo_pipeline_node_a
+                    node_b:
+                        handler: sermos_demo_client.workers.demo_pipeline.demo_pipeline_node_b
+                        queue: node-b-queue
+                    node_c:
+                        handler: sermos_demo_client.workers.demo_pipeline.demo_pipeline_node_c
+
+    scheduledTasks:
+        demo-model-task:
+            name: Demo Model Task
+            enabled: true
+            config:
+                scheduleType: interval
+                task: sermos_demo_client.workers.demo_worker.demo_model_task
+                queue: default-task-queue
+                schedule:
+                    every: 60
+                    period: seconds
+            schemaVersion: 1
+
 """
 import re
 import os
@@ -89,41 +160,22 @@ class ServiceRequestsSchema(Schema):
         description="Baseline (min) scale of this service to have available.",
         default=1,
         example=1)
-    # servicePreference = fields.String(
-    #     required=False,
-    #     validate=OneOf(['availability', 'cost'])
-    #     description="Tell Sermos to optimize for availability or cost.",
-    #     example="cost"
-    # )
-    # scalingMethod = fields.String(
-    #     required=False,
-    #     validate=OneOf(['manual', 'queue', 'cpu', 'memory'])
-    #     description="Method for this worker to scale up/down.",
-    #     default="manual",
-    #     example="manual"
-    # )
-    # scalingQueueName = fields.String(
-    #     required=False,
-    #     description="Queue to watch to scale. Required for `queue` scaling",
-    #     default="default",
-    #     example="my-special-queue"
-    # )
-    # scalingMaxReplicaCount = fields.Integer(
-    #     required=False,
-    #     description="Maximum scale of this service to have available.",
-    #     default=1,
-    #     example=10
-    # )
-    # cpuRequest = fields.Float(
-    #     required=False,
-    #     description="CPUs expected to be available for each replica.",
-    #     default=0.5,
-    #     example="0.5")
-    # memoryRequest = fields.Float(
-    #     required=False,
-    #     description="Memory (in GB) expected to be available for each replica.",
-    #     default=0.5,
-    #     example="0.5 (means half of one GB)")
+    cpuRequest = fields.Float(
+        required=True,
+        description="Requested CPUs to be available for each replica.",
+        default=0.5,
+        example="0.5")
+    memoryRequest = fields.Float(
+        required=True,
+        description="Requested memory (in GB) to be available for each replica.",
+        default=0.5,
+        example="0.5 (means half of 1 GB)")
+    ephemeralStorageRequest = fields.Float(
+        required=True,
+        description="Requested ephemeral storage (in GB) to "
+                    "be available for each replica.",
+        default=8,
+        example="2 (means 2 GB)")
     cpuLimit = fields.Float(
         required=False,
         description="Maximum CPUs to be available for each replica.",
@@ -134,6 +186,12 @@ class ServiceRequestsSchema(Schema):
         description="Maximum memory (in GB) to be available for each replica.",
         default=0.5,
         example="0.5 (means half of 1 GB)")
+    ephemeralStorageLimit = fields.Float(
+        required=False,
+        description="Maximum ephemeral storage (in GB) to "
+                    "be available for each replica.",
+        default=8,
+        example="2 (means 2 GB)")
 
 
 class NameSchema(Schema):
@@ -317,18 +375,15 @@ class SermosYamlSchema(ExcludeUnknownSchema, EnvironmentVariablesSchema):
         description="List of workers for Sermos to manage.",
         required=True)
 
-    pipelines = fields.Dict(
-        keys=fields.String(),
-        values=fields.Nested(BasePipelineSchema),
-        description="List of pipelines",
-        required=False)
-
-    scheduledTasks = fields.Dict(
-        keys=fields.String(),
-        values=fields.Nested(BaseScheduleSchema),
-        description="List of scheduled tasks",
-        required=False)
+    pipelines = fields.Dict(keys=fields.String(),
+                            values=fields.Nested(BasePipelineSchema),
+                            description="List of pipelines",
+                            required=False)
 
+    scheduledTasks = fields.Dict(keys=fields.String(),
+                                 values=fields.Nested(BaseScheduleSchema),
+                                 description="List of scheduled tasks",
+                                 required=False)
 
     def validate_errors(self, schema: Schema, value: dict):
         """ Run Marshmallow validate() and raise if any errors
@@ -584,6 +639,9 @@ def load_sermos_config(pkg_name: str = None,
                 configuration as a dictionary. If false, return the loaded
                 string value of the yaml file.
     """
+    if sermos_yaml_filename is None:
+        sermos_yaml_filename = SERMOS_YAML_PATH
+
     logger.info(f"Loading `sermos.yaml` from package `{pkg_name}` "
                 f"and file location `{sermos_yaml_filename}` ...")
     sermos_config = None
@@ -593,9 +651,6 @@ def load_sermos_config(pkg_name: str = None,
         logger.warning("Unable to retrieve sermos.yaml configuration ...")
         return sermos_config
 
-    if sermos_yaml_filename is None:
-        sermos_yaml_filename = SERMOS_YAML_PATH
-
     try:
         sermos_config_path = pkg_resources.resource_filename(
             pkg_name, sermos_yaml_filename)
